@@ -54,7 +54,6 @@ class Backtesting:
 
     async def stop(self):
         await self.delete_time_channel()
-        self.time_updater.backtesting = None
 
     async def delete_time_channel(self):
         await self.time_channel.stop()
@@ -100,3 +99,6 @@ class Backtesting:
 
     def _has_nothing_to_do(self):
         return not self.time_manager or self.time_manager.get_total_iteration() == 0
+
+    def has_finished(self):
+        return self.time_updater and self.time_updater.finished_event.is_set()
