@@ -17,9 +17,12 @@ import asyncio
 import json
 import os.path as path
 import os
-import aiohttp 
+import time
+
+import aiohttp
 
 import octobot_commons.logging as logging
+import octobot_commons.databases as databases
 
 import octobot_backtesting.enums as enums
 import octobot_backtesting.constants as constants
@@ -38,33 +41,51 @@ class DataCollector:
         self.logger = logging.get_logger(self.__class__.__name__)
 
         self.should_stop = False
-        self.file_name = data.get_backtesting_file_name(self.__class__, data_format)
+        self.file_name = data.get_backtesting_file_name(self.__class__,
+                                                        self.get_file_identifier,
+                                                        data_format=data_format)
 
         self.database = None
         self.aiohttp_session = None
         self.file_path = None
+        self.temp_file_path = None
+        self.finished = False
+        self.in_progress = False
         self._ensure_file_path()
         self.set_file_path()
 
     async def initialize(self) -> None:
         pass
 
-    async def stop(self) -> None:
+    def get_file_identifier(self):
+        return time.time()
+
+    async def stop(self, **kwargs) -> None:
         self.should_stop = True
 
     async def start(self) -> None:
         raise NotImplementedError("Start is not implemented")
 
+    def is_in_progress(self):
+        return self.in_progress
+
+    def is_finished(self):
+        return self.finished
+
     def _ensure_file_path(self):
         if not path.isdir(self.path):
             os.makedirs(self.path)
 
     def set_file_path(self) -> None:
         self.file_path = path.join(self.path, self.file_name) if self.path else self.file_name
+        self.temp_file_path = self.file_path + constants.BACKTESTING_DATA_FILE_TEMP_EXT
 
     def create_database(self) -> None:
         if not self.database:
-            self.database = data.DataBase(self.file_path)
+            self.database = databases.SQLiteDatabase(self.temp_file_path)
+
+    def finalize_database(self):
+        os.rename(self.temp_file_path, self.file_path)
 
     def create_aiohttp_session(self) -> None:
         if not self.aiohttp_session:
