@@ -1,4 +1,4 @@
-#  Drakkar-Software OctoBot
+#  Drakkar-Software OctoBot-Backtesting
 #  Copyright (c) Drakkar-Software, All rights reserved.
 #
 #  This library is free software; you can redistribute it and/or
@@ -20,6 +20,7 @@ import abc
 import time
 
 import octobot_commons.constants as commons_constants
+import octobot_commons.enums as commons_enums
 import octobot_backtesting.collectors.data_collector as data_collector
 import octobot_backtesting.enums as enums
 import octobot_backtesting.importers as importers
@@ -31,19 +32,37 @@ except ImportError:
 
 
 class ExchangeDataCollector(data_collector.DataCollector):
-    VERSION = "1.0"
+    VERSION = "1.1"
     IMPORTER = importers.ExchangeDataImporter
 
     def __init__(self, config, exchange_name, tentacles_setup_config, symbols, time_frames, use_all_available_timeframes=False,
-                 data_format=enums.DataFormats.REGULAR_COLLECTOR_DATA):
+                 data_format=enums.DataFormats.REGULAR_COLLECTOR_DATA, start_timestamp=None, end_timestamp=None):
         super().__init__(config, data_format=data_format)
         self.exchange_name = exchange_name
         self.tentacles_setup_config = tentacles_setup_config
         self.symbols = symbols if symbols else []
         self.time_frames = time_frames if time_frames else []
         self.use_all_available_timeframes = use_all_available_timeframes
+        self.start_timestamp = start_timestamp
+        self.end_timestamp = end_timestamp
+        self.current_step_index = 0
+        self.total_steps = 0
+        self.current_step_percent = 0
+        self.exchange_id = None
         self.set_file_path()
 
+    def register_exchange_id(self, exchange_id):
+        self.exchange_id = exchange_id
+
+    def get_current_step_index(self):
+        return self.current_step_index
+
+    def get_total_steps(self):
+        return self.total_steps
+
+    def get_current_step_percent(self):
+        return self.current_step_percent
+
     @abc.abstractmethod
     def _load_all_available_timeframes(self):
         raise NotImplementedError("_load_all_available_timeframes is not implemented")
@@ -69,7 +88,10 @@ class ExchangeDataCollector(data_collector.DataCollector):
                                    version=self.VERSION,
                                    exchange=self.exchange_name,
                                    symbols=json.dumps(self.symbols),
-                                   time_frames=json.dumps([tf.value for tf in self.time_frames]))
+                                   time_frames=json.dumps([tf.value for tf in self.time_frames]),
+                                   start_timestamp=int(self.start_timestamp/1000) if self.start_timestamp else 0,
+                                   end_timestamp=int(self.end_timestamp/1000) if self.end_timestamp
+                                   else int(time.time()) if self.start_timestamp else 0)
 
     async def save_ticker(self, timestamp, exchange, cryptocurrency, symbol, ticker, multiple=False):
         if not multiple:
