@@ -15,8 +15,6 @@
 #  License along with this library.
 
 from octobot_backtesting.data import data_file_manager
-from octobot_backtesting.data import database
-
 from octobot_backtesting.data.data_file_manager import (
     get_backtesting_file_name,
     get_data_type,
@@ -28,9 +26,6 @@ from octobot_backtesting.data.data_file_manager import (
     get_database_description,
     get_file_description,
 )
-from octobot_backtesting.data.database import (
-    DataBase,
-)
 
 __all__ = [
     "get_backtesting_file_name",
@@ -42,5 +37,4 @@ __all__ = [
     "delete_data_file",
     "get_database_description",
     "get_file_description",
-    "DataBase",
 ]
