@@ -24,7 +24,13 @@ class DataFormatKeys(enum.Enum):
     SYMBOLS = "symbols"
     EXCHANGE = "exchange"
     DATE = "date"
+    TIMESTAMP = "timestamp"
+    START_TIMESTAMP = "start_timestamp"
+    END_TIMESTAMP = "end_timestamp"
+    START_DATE = "start_date"
+    END_DATE = "end_date"
     CANDLES = "candles"
+    CANDLES_LENGTH = "candles_length"
     TIME_FRAMES = "time_frames"
     TYPE = "type"
     VERSION = "version"
@@ -36,11 +42,6 @@ class ReportFormat(enum.Enum):
     SYMBOLS_WITH_TF = "symbols_with_time_frames_frames"
 
 
-class DataBaseOrderBy(enum.Enum):
-    ASC = "ASC"
-    DESC = "DESC"
-
-
 class DataTables(enum.Enum):
     DESCRIPTION = "description"
 
@@ -51,11 +52,4 @@ class ExchangeDataTables(enum.Enum):
     OHLCV = "ohlcv"
     KLINE = "kline"
     TICKER = "ticker"
-
-
-class DataBaseOperations(enum.Enum):
-    SUP = ">"
-    INF = "<"
-    EQUALS = "="
-    INF_EQUALS = f"{INF}{EQUALS}"
-    SUP_EQUALS = f"{SUP}{EQUALS}"
+    FUNDING = "funding"
