@@ -14,11 +14,11 @@
 #  You should have received a copy of the GNU Lesser General Public
 #  License along with this library.
 
-class DataBaseNotExists(Exception):
+class DataCollectorError(Exception):
     pass
 
 
-class DataCollectorError(Exception):
+class IncompatibleDatafileError(Exception):
     pass
 
 
